@@ -8,7 +8,7 @@ master_doc = 'index'
 project = u'sphinx theme for basicstrap style'
 copyright = u'2013, tell-k'
 
-version = '0.3.0'
+version = '0.3.1'
 
 # -- Options for HTML output ---------------------------------------------------
 
@@ -34,7 +34,7 @@ html_theme_options = {
     'header_inverse': False,
     'relbar_inverse': False,
     'inner_theme': True,
-    'inner_theme_name': 'geo-bootstrap',
+    'inner_theme_name': 'bootswatch-flatly',
     'h1_size': '3.0em',
     'h2_size': '2.6em',
     'h3_size': '2.2em',
